Computes the predicted survival function of a previously fitted deepAFT or deepSurv model.
## S3 method for class 'deepAFT' or 'deepSurv'
# S3 method for dSurv
survfit(formula, se.fit=TRUE, conf.int=.95, ...)
survfit.deepAFT returns a list of predicted baseline survival function, cumulative hazard function and residuals.
Predicted baseline survival function for T0=T/exp(mu).
Baseline cumulative hazard function, -log(surv).
Baseline hazard function.
Variance of the baseline hazard.
Martingale residuals of the (deepAFT) model.
Standard error for the cumulative hazard function, if se.fit = TRUE.
See survfit for more detail about other output values such as upper, lower, conf.type.
Confidence interval is based on log-transformation of survival function.
a deepAFT or deepSurv fit object.
a logical value indicating whether standard errors shall be computed. Default is TRUE
the level for a two-sided confidence interval on the survival curve. Default is 0.95
other unused arguments.
Bingshu E. Chen
survfit.dSurv is called to compuate baseline survival function S_T0(t) from the deepAFT model deepAFT, where T0 = T/exp(mu), or log(T) = log(T) - mu.
For the deepSurv model deepAFT, survfit.dSurv evaluates the Nelson-Aalen estimate of the baseline survival function.
The default method, survfit has its own help page. Use methods("survfit") to get all the methods for the survfit generic.
The default method for survfit survfit,
predict.dSurv